package main

import (
	"fmt"
	"golang.org/x/net/proxy"
	"io"
	"net/http"
	"net/url"
	"strconv"
	"time"
)

const (
	ProxyHost = "flow.hailiangip.com"   // 请求的ip地址
	DestUrl   = "http://www.baidu.com"  // 目标地址
	OrderId   = ""                      // 订单号
	Pid       = "-1"                    // 省份id，-1表示随机
	Cid       = "-1"                    // 城市id，-1表示随机
	Sip       = "0"                     // 是否切换ip，0表示自动切换，1表示不能切换，默认0
	Uid       = ""                      // 自定义，dik情况下，相同的uid会尽可能采用相同的ip，可以认为是同一组会话，不填表示每次请求都随机
	ZoneId    = ""                      // 通道ID
	PWD       = ""                      // 订单密码
)

const (
	HttpProxyPort   = 14223 // http代理端口
	Socks5ProxyPort = 14224 // socks5代理端口
)

/**
	流量订单Demo 基于go1.19
*/
func main() {
	// 用户名
	username := ""
	// password，是由以上参数组合而成的，用 '&' 符号分隔，pwd和time必传
	password := ""
	// 模式，0-默认账密模式，1-通道模式。此变量只是为了代码上拼接2种使用方式的password参数
	mode := 0

	if mode == 0 {
		// 默认账密模式
		username = OrderId
		password = password + "pwd=" + PWD + "&pid=" + Pid + "&cid=" + Cid + "&uid=" + Uid + "&sip=" + Sip
	} else if mode == 1 {
		//通道模式
		username = OrderId
		password = password + "pwd=" + PWD + "&zoneId=" + ZoneId
	}
	httpProxyWithPassRequest(DestUrl, username, password)
	socks5ProxyWithPassRequest(DestUrl, username, password)
}

func httpProxyWithPassRequest(destUrl string, username string, proxyPassword string) {
	proxyUrl, _ := url.Parse(fmt.Sprintf("http://%s:%s@%s:%s", username, proxyPassword, ProxyHost, strconv.Itoa(HttpProxyPort)))
	httpClient := &http.Client{
		Transport: &http.Transport{
			Proxy: http.ProxyURL(proxyUrl),
		},
		Timeout: 6 * time.Second,
	}
	resp, err := httpClient.Get(destUrl)
	if err != nil {
		panic(err)
	}
	defer resp.Body.Close()
	data, _ := io.ReadAll(resp.Body)
	fmt.Println("http代理请求状态码: " + strconv.Itoa(resp.StatusCode))
	fmt.Println("http代理请求响应内容: " + string(data))
}

func socks5ProxyWithPassRequest(destUrl string, username string, proxyPassword string) {
	address := fmt.Sprintf("%s:%s", ProxyHost, strconv.Itoa(Socks5ProxyPort))
	// 设置代理认证
	auth := &proxy.Auth{
		User:     username,
		Password: proxyPassword,
	}
	dialer, err := proxy.SOCKS5("tcp", address, auth, proxy.Direct)
	if err != nil {
		panic(err)
	}
	httpClient := &http.Client{
		Transport: &http.Transport{
			Dial: dialer.Dial,
		},
		Timeout: 6 * time.Second,
	}

	req, _ := http.NewRequest(http.MethodGet, destUrl, nil)
	resp, err := httpClient.Do(req)
	if err != nil {
		panic(err)
	}
	defer resp.Body.Close()
	data, _ := io.ReadAll(resp.Body)
	fmt.Println("socks5代理请求状态码: " + strconv.Itoa(resp.StatusCode))
	fmt.Println("socks5代理请求响应内容: " + string(data))
}